==> r2r-3.3.22-py3-none-any.whl: core/base/abstractions/__init__.py <==
from shared.abstractions.base import AsyncSyncMeta, R2RSerializable, syncable
from shared.abstractions.document import (
    Document,
    DocumentChunk,
    DocumentResponse,
    DocumentType,
    IngestionStatus,
    KGEnrichmentStatus,
    KGExtractionStatus,
    RawChunk,
    UnprocessedChunk,
    UpdateChunk,
)
from shared.abstractions.embedding import (
    EmbeddingPurpose,
    default_embedding_prefixes,
)
from shared.abstractions.exception import (
    R2RDocumentProcessingError,
    R2RException,
)
from shared.abstractions.graph import (
    Community,
    Entity,
    Graph,
    KGExtraction,
    Relationship,
    StoreType,
)
from shared.abstractions.ingestion import (
    ChunkEnrichmentSettings,
    ChunkEnrichmentStrategy,
)
from shared.abstractions.kg import (
    GraphCommunitySettings,
    KGCreationSettings,
    KGEnrichmentSettings,
    KGRunType,
)
from shared.abstractions.llm import (
    GenerationConfig,
    LLMChatCompletion,
    LLMChatCompletionChunk,
    Message,
    MessageType,
    RAGCompletion,
)
from shared.abstractions.prompt import Prompt
from shared.abstractions.search import (
    AggregateSearchResult,
    ChunkSearchResult,
    ChunkSearchSettings,
    GraphSearchResult,
    GraphSearchSettings,
    HybridSearchSettings,
    KGCommunityResult,
    KGEntityResult,
    KGRelationshipResult,
    KGSearchResultType,
    SearchMode,
    SearchSettings,
    WebSearchResponse,
    select_search_filters,
)
from shared.abstractions.user import Token, TokenData, User
from shared.abstractions.vector import (
    IndexArgsHNSW,
    IndexArgsIVFFlat,
    IndexConfig,
    IndexMeasure,
    IndexMethod,
    StorageResult,
    Vector,
    VectorEntry,
    VectorQuantizationSettings,
    VectorQuantizationType,
    VectorTableName,
    VectorType,
)

__all__ = [
    # Base abstractions
    "R2RSerializable",
    "AsyncSyncMeta",
    "syncable",
    # Completion abstractions
    "MessageType",
    # Document abstractions
    "Document",
    "DocumentChunk",
    "DocumentResponse",
    "DocumentType",
    "IngestionStatus",
    "KGExtractionStatus",
    "KGEnrichmentStatus",
    "RawChunk",
    "UnprocessedChunk",
    "UpdateChunk",
    # Embedding abstractions
    "EmbeddingPurpose",
    "default_embedding_prefixes",
    # Exception abstractions
    "R2RDocumentProcessingError",
    "R2RException",
    # Graph abstractions
    "Entity",
    "Community",
    "StoreType",
    "KGExtraction",
    "Relationship",
    # Index abstractions
    "IndexConfig",
    # LLM abstractions
    "GenerationConfig",
    "LLMChatCompletion",
    "LLMChatCompletionChunk",
    "Message",
    "RAGCompletion",
    # Prompt abstractions
    "Prompt",
    # Search abstractions
    "WebSearchResponse",
    "AggregateSearchResult",
    "GraphSearchResult",
    "KGSearchResultType",
    "KGEntityResult",
    "KGRelationshipResult",
    "KGCommunityResult",
    "GraphSearchSettings",
    "ChunkSearchSettings",
    "ChunkSearchResult",
    "SearchSettings",
    "select_search_filters",
    "SearchMode",
    "HybridSearchSettings",
    # KG abstractions
    "KGCreationSettings",
    "KGEnrichmentSettings",
    "GraphCommunitySettings",
    "KGRunType",
    # User abstractions
    "Token",
    "TokenData",
    "User",
    # Vector abstractions
    "Vector",
    "VectorEntry",
    "VectorType",
    "IndexMeasure",
    "IndexMethod",
    "VectorTableName",
    "IndexArgsHNSW",
    "IndexArgsIVFFlat",
    "VectorQuantizationSettings",
    "VectorQuantizationType",
    "StorageResult",
    "ChunkEnrichmentSettings",
    "ChunkEnrichmentStrategy",
]

==> r2r-3.3.40-py3-none-any.whl: core/base/abstractions/__init__.py <==
from shared.abstractions.base import AsyncSyncMeta, R2RSerializable, syncable
from shared.abstractions.document import (
    ChunkEnrichmentSettings,
    Document,
    DocumentChunk,
    DocumentResponse,
    DocumentType,
    GraphConstructionStatus,
    GraphExtractionStatus,
    IngestionStatus,
    RawChunk,
    UnprocessedChunk,
    UpdateChunk,
)
from shared.abstractions.embedding import (
    EmbeddingPurpose,
    default_embedding_prefixes,
)
from shared.abstractions.exception import (
    R2RDocumentProcessingError,
    R2RException,
)
from shared.abstractions.graph import (
    Community,
    Entity,
    Graph,
    GraphCommunitySettings,
    GraphCreationSettings,
    GraphEnrichmentSettings,
    GraphExtraction,
    Relationship,
    StoreType,
)
from shared.abstractions.llm import (
    GenerationConfig,
    LLMChatCompletion,
    LLMChatCompletionChunk,
    Message,
    MessageType,
    RAGCompletion,
)
from shared.abstractions.prompt import Prompt
from shared.abstractions.search import (
    AggregateSearchResult,
    ChunkSearchResult,
    ChunkSearchSettings,
    ContextDocumentResult,
    GraphCommunityResult,
    GraphEntityResult,
    GraphRelationshipResult,
    GraphSearchResult,
    GraphSearchResultType,
    GraphSearchSettings,
    HybridSearchSettings,
    SearchMode,
    SearchSettings,
    WebSearchResponse,
    select_search_filters,
)
from shared.abstractions.user import Token, TokenData, User
from shared.abstractions.vector import (
    IndexArgsHNSW,
    IndexArgsIVFFlat,
    IndexConfig,
    IndexMeasure,
    IndexMethod,
    StorageResult,
    Vector,
    VectorEntry,
    VectorQuantizationSettings,
    VectorQuantizationType,
    VectorTableName,
    VectorType,
)

__all__ = [
    # Base abstractions
    "R2RSerializable",
    "AsyncSyncMeta",
    "syncable",
    # Completion abstractions
    "MessageType",
    # Document abstractions
    "Document",
    "DocumentChunk",
    "DocumentResponse",
    "DocumentType",
    "IngestionStatus",
    "GraphExtractionStatus",
    "GraphConstructionStatus",
    "RawChunk",
    "UnprocessedChunk",
    "UpdateChunk",
    # Embedding abstractions
    "EmbeddingPurpose",
    "default_embedding_prefixes",
    # Exception abstractions
    "R2RDocumentProcessingError",
    "R2RException",
    # Graph abstractions
    "Entity",
    "Community",
    "StoreType",
    "GraphExtraction",
    "Relationship",
    # Index abstractions
    "IndexConfig",
    # LLM abstractions
    "GenerationConfig",
    "LLMChatCompletion",
    "LLMChatCompletionChunk",
    "Message",
    "RAGCompletion",
    # Prompt abstractions
    "Prompt",
    # Search abstractions
    "WebSearchResponse",
    "ContextDocumentResult",
    "AggregateSearchResult",
    "GraphSearchResult",
    "GraphSearchResultType",
    "GraphEntityResult",
    "GraphRelationshipResult",
    "GraphCommunityResult",
    "GraphSearchSettings",
    "ChunkSearchSettings",
    "ChunkSearchResult",
    "SearchSettings",
    "select_search_filters",
    "SearchMode",
    "HybridSearchSettings",
    # Graph abstractions
    "GraphCreationSettings",
    "GraphEnrichmentSettings",
    "GraphCommunitySettings",
    # User abstractions
    "Token",
    "TokenData",
    "User",
    # Vector abstractions
    "Vector",
    "VectorEntry",
    "VectorType",
    "IndexMeasure",
    "IndexMethod",
    "VectorTableName",
    "IndexArgsHNSW",
    "IndexArgsIVFFlat",
    "VectorQuantizationSettings",
    "VectorQuantizationType",
    "StorageResult",
    "ChunkEnrichmentSettings",
]
